pub enum MomentValue {
Value(f32),
BelowThreshold,
RangeFolded,
}Expand description
The data moment value for a product in a radial’s gate. The value may be a floating-point number or a special case such as “below threshold” or “range folded”.
Variants
Value(f32)
The data moment value for a gate.
BelowThreshold
The value for this gate was below the signal threshold.
RangeFolded
The value for this gate exceeded the maximum unambiguous range.