pub struct MomentData { /* private fields */ }Expand description
Moment data from a radial for a particular product where each value corresponds to a gate.
Implementations
Sourceimpl MomentData
impl MomentData
Sourcepub fn from_fixed_point(scale: f32, offset: f32, values: Vec<u8>) -> Self
pub fn from_fixed_point(scale: f32, offset: f32, values: Vec<u8>) -> Self
Create new moment data from fixed-point encoding.
Sourcepub fn values(&self) -> Vec<MomentValue>
pub fn values(&self) -> Vec<MomentValue>
Values from this data moment corresponding to gates in the radial.