Radial

Struct Radial 

pub struct Radial { /* private fields */ }
A single radar ray composed of a series of gates. This represents a single azimuth angle and elevation angle pair at a point in time and contains the Level II data (reflectivity, velocity, and spectrum width) for each range gate in that ray. The range of the radar and gate interval distance determines the resolution of the ray and the number of gates in the ray.

Implementations

Source

impl Radial

pub fn new( collection_timestamp: i64, azimuth_number: u16, azimuth_angle_degrees: f32, azimuth_spacing_degrees: f32, radial_status: RadialStatus, elevation_number: u8, elevation_angle_degrees: f32, reflectivity: Option<MomentData>, velocity: Option<MomentData>, spectrum_width: Option<MomentData>, differential_reflectivity: Option<MomentData>, differential_phase: Option<MomentData>, correlation_coefficient: Option<MomentData>, specific_differential_phase: Option<MomentData>, ) -> Self

Create a new radial with the given properties.

pub fn collection_timestamp(&self) -> i64

The collection timestamp in milliseconds since midnight Jan 1, 1970 (epoch/UNIX timestamp).

pub fn azimuth_number(&self) -> u16

The index number for this radial’s azimuth in the elevation sweep, ranging up to 720 depending on the azimuthal resolution.

pub fn azimuth_angle_degrees(&self) -> f32

Azimuth angle this radial’s data was collected at in degrees.

pub fn azimuth_spacing_degrees(&self) -> f32

Azimuthal distance between radials in the sweep in degrees.

pub fn radial_status(&self) -> RadialStatus

The radial’s position in the sequence of radials making up a scan.

pub fn elevation_number(&self) -> u8

The elevation number for this radial in the volume scan.

pub fn elevation_angle_degrees(&self) -> f32

Elevation angle this radial’s data was collected at in degrees.

pub fn reflectivity(&self) -> Option<&MomentData>

Reflectivity data for this radial if available.

pub fn velocity(&self) -> Option<&MomentData>

Velocity data for this radial if available.

pub fn spectrum_width(&self) -> Option<&MomentData>

Spectrum width data for this radial if available.

pub fn differential_reflectivity(&self) -> Option<&MomentData>

Differential reflectivity data for this radial if available.

pub fn differential_phase(&self) -> Option<&MomentData>

Differential phase data for this radial if available.

pub fn correlation_coefficient(&self) -> Option<&MomentData>

Correlation coefficient data for this radial if available.

pub fn specific_differential_phase(&self) -> Option<&MomentData>

Specific differential phase data for this radial if available.