pub struct Sweep { /* private fields */ }Expand description
A single radar sweep composed of a series of radials. This represents a full rotation of the radar at some elevation angle and contains the Level II data (reflectivity, velocity, and spectrum width) for each azimuth angle in that sweep. The resolution of the sweep dictates the azimuthal distance between rays and thus and number of rays in the sweep. Multiple sweeps are taken at different elevation angles to create a volume scan.
Implementations
Sourceimpl Sweep
impl Sweep
Sourcepub fn new(elevation_number: u8, radials: Vec<Radial>) -> Self
pub fn new(elevation_number: u8, radials: Vec<Radial>) -> Self
Create a new radar sweep with the given elevation number and radials.
Sourcepub fn from_radials(radials: Vec<Radial>) -> Vec<Self>
pub fn from_radials(radials: Vec<Radial>) -> Vec<Self>
Create a new radar sweep from a list of radials by splitting them by elevation.
Sourcepub fn elevation_number(&self) -> u8
pub fn elevation_number(&self) -> u8
The index number for this radial’s elevation in the volume scan. The precise elevation angle varies and can be found in individual radials.